from .base import (
    KeywordPlanCampaignServiceTransport as KeywordPlanCampaignServiceTransport,
)
from .grpc import (
    KeywordPlanCampaignServiceGrpcTransport as KeywordPlanCampaignServiceGrpcTransport,
)
