from .base import (
    KeywordPlanCampaignKeywordServiceTransport as KeywordPlanCampaignKeywordServiceTransport,
)
from .grpc import (
    KeywordPlanCampaignKeywordServiceGrpcTransport as KeywordPlanCampaignKeywordServiceGrpcTransport,
)
