from .base import (
    CustomConversionGoalServiceTransport as CustomConversionGoalServiceTransport,
)
from .grpc import (
    CustomConversionGoalServiceGrpcTransport as CustomConversionGoalServiceGrpcTransport,
)
