from .base import (
    ThirdPartyAppAnalyticsLinkServiceTransport as ThirdPartyAppAnalyticsLinkServiceTransport,
)
from .grpc import (
    ThirdPartyAppAnalyticsLinkServiceGrpcTransport as ThirdPartyAppAnalyticsLinkServiceGrpcTransport,
)
