from .base import (
    ConversionAdjustmentUploadServiceTransport as ConversionAdjustmentUploadServiceTransport,
)
from .grpc import (
    ConversionAdjustmentUploadServiceGrpcTransport as ConversionAdjustmentUploadServiceGrpcTransport,
)
