from .base import (
    RecommendationSubscriptionServiceTransport as RecommendationSubscriptionServiceTransport,
)
from .grpc import (
    RecommendationSubscriptionServiceGrpcTransport as RecommendationSubscriptionServiceGrpcTransport,
)
