from .base import (
    CampaignConversionGoalServiceTransport as CampaignConversionGoalServiceTransport,
)
from .grpc import (
    CampaignConversionGoalServiceGrpcTransport as CampaignConversionGoalServiceGrpcTransport,
)
