from .base import (
    BiddingSeasonalityAdjustmentServiceTransport as BiddingSeasonalityAdjustmentServiceTransport,
)
from .grpc import (
    BiddingSeasonalityAdjustmentServiceGrpcTransport as BiddingSeasonalityAdjustmentServiceGrpcTransport,
)
