from .base import (
    CustomerManagerLinkServiceTransport as CustomerManagerLinkServiceTransport,
)
from .grpc import (
    CustomerManagerLinkServiceGrpcTransport as CustomerManagerLinkServiceGrpcTransport,
)
