from .base import (
    ConversionGoalCampaignConfigServiceTransport as ConversionGoalCampaignConfigServiceTransport,
)
from .grpc import (
    ConversionGoalCampaignConfigServiceGrpcTransport as ConversionGoalCampaignConfigServiceGrpcTransport,
)
