from .base import (
    CampaignLifecycleGoalServiceTransport as CampaignLifecycleGoalServiceTransport,
)
from .grpc import (
    CampaignLifecycleGoalServiceGrpcTransport as CampaignLifecycleGoalServiceGrpcTransport,
)
