from .base import (
    CustomerNegativeCriterionServiceTransport as CustomerNegativeCriterionServiceTransport,
)
from .grpc import (
    CustomerNegativeCriterionServiceGrpcTransport as CustomerNegativeCriterionServiceGrpcTransport,
)
