from .base import (
    AccountBudgetProposalServiceTransport as AccountBudgetProposalServiceTransport,
)
from .grpc import (
    AccountBudgetProposalServiceGrpcTransport as AccountBudgetProposalServiceGrpcTransport,
)
