from .base import (
    TravelAssetSuggestionServiceTransport as TravelAssetSuggestionServiceTransport,
)
from .grpc import (
    TravelAssetSuggestionServiceGrpcTransport as TravelAssetSuggestionServiceGrpcTransport,
)
