from .base import (
    ProductLinkInvitationServiceTransport as ProductLinkInvitationServiceTransport,
)
from .grpc import (
    ProductLinkInvitationServiceGrpcTransport as ProductLinkInvitationServiceGrpcTransport,
)
