from .base import (
    CustomerLifecycleGoalServiceTransport as CustomerLifecycleGoalServiceTransport,
)
from .grpc import (
    CustomerLifecycleGoalServiceGrpcTransport as CustomerLifecycleGoalServiceGrpcTransport,
)
