from .base import (
    SmartCampaignSettingServiceTransport as SmartCampaignSettingServiceTransport,
)
from .grpc import (
    SmartCampaignSettingServiceGrpcTransport as SmartCampaignSettingServiceGrpcTransport,
)
